---
title: 영중소 수수료율 기준
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 영중소 수수료율 기준
  description: >-
    PG사 수수료율은 2019년 1월 31일부터 정부 정책에 따라 매출 규모에 따라 영세, 중소 사업자에 대한 우대수수료율이 적용됩니다.
    신규 서비스(매출이 발생되지 않은 사업자)는 첫 세금 신고 전까지 '일반사업자'로 적용됩니다.
  keywords:
    - 공통
    - PG사 요금
tags:
  - 공통
  - 결제대행사 계약
  - 수수료
pgCompanies:
  - 공통
searchTags:
  - PG사 수수료
  - PG수수료
  - PG 수수료
  - PG 요금
  - PG사 요금
  - PG사요금
  - PG요금
  - 결제 요금
  - 결제요금
  - 수수료 기준
  - 수수료기준
  - 영세 사업자
  - 중소 사업자
  - 영세사업자
  - 중소사업자
  - 영중소수수료
  - 매출
  - 수수료율
  - 중소
  - 영세
  - 영중소 수수료
  - 수수료
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="PG사 수수료율은 2019년 1월 31일부터 정부 정책에 따라 
매출액 기준으로 영세, 중소 사업자에 대한 우대 수수료율이 적용됩니다." title="" />

- 적용 시점 : 매년 반기별(1월/7월) 적용
- 적용 방법 : 국세청으로부터 영세/중소 신용카드 사업장의 사업자 명단을 PG사로 전달하고, PG사에서는 해당 매출액을 기준으로 수수료율 자동 적용 (PG사별 어드민 페이지 및 공지사항 참조)됩니다.
- 참고 : 신규 서비스(매출이 발생되지 않은 사업자)는 첫 세금 신고 전까지 **`"일반사업자"`** 로 적용됩니다.

<Callout content="영세 사업자 : ~ 3억원 미만
중소1 사업자 : 3억원 ~ 5억원 미만
중소2 사업자 : 5억원 ~ 10억원 미만
중소3 사업자 : 10억원 ~ 30억원 미만
일반 사업자 : 30억원 초과 " title=" 영중소 구분 : 연 매출액 기준" icon="💡" />
